# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.kind_attributes import KindAttributes
    from datadog_api_client.v2.model.kind_metadata import KindMetadata


class KindData(ModelNormal):
    validations = {
        "id": {
            "min_length": 1,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.kind_attributes import KindAttributes
        from datadog_api_client.v2.model.kind_metadata import KindMetadata

        return {
            "attributes": (KindAttributes,),
            "id": (str,),
            "meta": (KindMetadata,),
            "type": (str,),
        }

    attribute_map = {
        "attributes": "attributes",
        "id": "id",
        "meta": "meta",
        "type": "type",
    }

    def __init__(
        self_,
        attributes: Union[KindAttributes, UnsetType] = unset,
        id: Union[str, UnsetType] = unset,
        meta: Union[KindMetadata, UnsetType] = unset,
        type: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Schema that defines the structure of a Kind object in the Software Catalog.

        :param attributes: Kind attributes.
        :type attributes: KindAttributes, optional

        :param id: A read-only globally unique identifier for the entity generated by Datadog.  User supplied values are ignored.
        :type id: str, optional

        :param meta: Kind metadata.
        :type meta: KindMetadata, optional

        :param type: Kind.
        :type type: str, optional
        """
        if attributes is not unset:
            kwargs["attributes"] = attributes
        if id is not unset:
            kwargs["id"] = id
        if meta is not unset:
            kwargs["meta"] = meta
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)
