# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.vulnerability_attributes import VulnerabilityAttributes
    from datadog_api_client.v2.model.vulnerability_relationships import VulnerabilityRelationships
    from datadog_api_client.v2.model.vulnerabilities_type import VulnerabilitiesType


class Vulnerability(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.vulnerability_attributes import VulnerabilityAttributes
        from datadog_api_client.v2.model.vulnerability_relationships import VulnerabilityRelationships
        from datadog_api_client.v2.model.vulnerabilities_type import VulnerabilitiesType

        return {
            "attributes": (VulnerabilityAttributes,),
            "id": (str,),
            "relationships": (VulnerabilityRelationships,),
            "type": (VulnerabilitiesType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "id": "id",
        "relationships": "relationships",
        "type": "type",
    }

    def __init__(
        self_,
        attributes: VulnerabilityAttributes,
        id: str,
        relationships: VulnerabilityRelationships,
        type: VulnerabilitiesType,
        **kwargs,
    ):
        """
        A single vulnerability

        :param attributes: The JSON:API attributes of the vulnerability.
        :type attributes: VulnerabilityAttributes

        :param id: The unique ID for this vulnerability.
        :type id: str

        :param relationships: Related entities object.
        :type relationships: VulnerabilityRelationships

        :param type: The JSON:API type.
        :type type: VulnerabilitiesType
        """
        super().__init__(kwargs)

        self_.attributes = attributes
        self_.id = id
        self_.relationships = relationships
        self_.type = type
