# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class VulnerabilityStatus(ModelSimple):
    """
    The vulnerability status.

    :param value: Must be one of ["Open", "Muted", "Remediated", "InProgress", "AutoClosed"].
    :type value: str
    """

    allowed_values = {
        "Open",
        "Muted",
        "Remediated",
        "InProgress",
        "AutoClosed",
    }
    OPEN: ClassVar["VulnerabilityStatus"]
    MUTED: ClassVar["VulnerabilityStatus"]
    REMEDIATED: ClassVar["VulnerabilityStatus"]
    INPROGRESS: ClassVar["VulnerabilityStatus"]
    AUTOCLOSED: ClassVar["VulnerabilityStatus"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


VulnerabilityStatus.OPEN = VulnerabilityStatus("Open")
VulnerabilityStatus.MUTED = VulnerabilityStatus("Muted")
VulnerabilityStatus.REMEDIATED = VulnerabilityStatus("Remediated")
VulnerabilityStatus.INPROGRESS = VulnerabilityStatus("InProgress")
VulnerabilityStatus.AUTOCLOSED = VulnerabilityStatus("AutoClosed")
