# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class VulnerabilityType(ModelSimple):
    """
    The vulnerability type.

    :param value: Must be one of ["AdminConsoleActive", "CodeInjection", "CommandInjection", "ComponentWithKnownVulnerability", "DangerousWorkflows", "DefaultAppDeployed", "DefaultHtmlEscapeInvalid", "DirectoryListingLeak", "EmailHtmlInjection", "EndOfLife", "HardcodedPassword", "HardcodedSecret", "HeaderInjection", "HstsHeaderMissing", "InsecureAuthProtocol", "InsecureCookie", "InsecureJspLayout", "LdapInjection", "MaliciousPackage", "MandatoryRemediation", "NoHttpOnlyCookie", "NoSameSiteCookie", "NoSqlMongoDbInjection", "PathTraversal", "ReflectionInjection", "RiskyLicense", "SessionRewriting", "SessionTimeout", "SqlInjection", "Ssrf", "StackTraceLeak", "TrustBoundaryViolation", "Unmaintained", "UntrustedDeserialization", "UnvalidatedRedirect", "VerbTampering", "WeakCipher", "WeakHash", "WeakRandomness", "XContentTypeHeaderMissing", "XPathInjection", "Xss"].
    :type value: str
    """

    allowed_values = {
        "AdminConsoleActive",
        "CodeInjection",
        "CommandInjection",
        "ComponentWithKnownVulnerability",
        "DangerousWorkflows",
        "DefaultAppDeployed",
        "DefaultHtmlEscapeInvalid",
        "DirectoryListingLeak",
        "EmailHtmlInjection",
        "EndOfLife",
        "HardcodedPassword",
        "HardcodedSecret",
        "HeaderInjection",
        "HstsHeaderMissing",
        "InsecureAuthProtocol",
        "InsecureCookie",
        "InsecureJspLayout",
        "LdapInjection",
        "MaliciousPackage",
        "MandatoryRemediation",
        "NoHttpOnlyCookie",
        "NoSameSiteCookie",
        "NoSqlMongoDbInjection",
        "PathTraversal",
        "ReflectionInjection",
        "RiskyLicense",
        "SessionRewriting",
        "SessionTimeout",
        "SqlInjection",
        "Ssrf",
        "StackTraceLeak",
        "TrustBoundaryViolation",
        "Unmaintained",
        "UntrustedDeserialization",
        "UnvalidatedRedirect",
        "VerbTampering",
        "WeakCipher",
        "WeakHash",
        "WeakRandomness",
        "XContentTypeHeaderMissing",
        "XPathInjection",
        "Xss",
    }
    ADMIN_CONSOLE_ACTIVE: ClassVar["VulnerabilityType"]
    CODE_INJECTION: ClassVar["VulnerabilityType"]
    COMMAND_INJECTION: ClassVar["VulnerabilityType"]
    COMPONENT_WITH_KNOWN_VULNERABILITY: ClassVar["VulnerabilityType"]
    DANGEROUS_WORKFLOWS: ClassVar["VulnerabilityType"]
    DEFAULT_APP_DEPLOYED: ClassVar["VulnerabilityType"]
    DEFAULT_HTML_ESCAPE_INVALID: ClassVar["VulnerabilityType"]
    DIRECTORY_LISTING_LEAK: ClassVar["VulnerabilityType"]
    EMAIL_HTML_INJECTION: ClassVar["VulnerabilityType"]
    END_OF_LIFE: ClassVar["VulnerabilityType"]
    HARDCODED_PASSWORD: ClassVar["VulnerabilityType"]
    HARDCODED_SECRET: ClassVar["VulnerabilityType"]
    HEADER_INJECTION: ClassVar["VulnerabilityType"]
    HSTS_HEADER_MISSING: ClassVar["VulnerabilityType"]
    INSECURE_AUTH_PROTOCOL: ClassVar["VulnerabilityType"]
    INSECURE_COOKIE: ClassVar["VulnerabilityType"]
    INSECURE_JSP_LAYOUT: ClassVar["VulnerabilityType"]
    LDAP_INJECTION: ClassVar["VulnerabilityType"]
    MALICIOUS_PACKAGE: ClassVar["VulnerabilityType"]
    MANDATORY_REMEDIATION: ClassVar["VulnerabilityType"]
    NO_HTTP_ONLY_COOKIE: ClassVar["VulnerabilityType"]
    NO_SAME_SITE_COOKIE: ClassVar["VulnerabilityType"]
    NO_SQL_MONGO_DB_INJECTION: ClassVar["VulnerabilityType"]
    PATH_TRAVERSAL: ClassVar["VulnerabilityType"]
    REFLECTION_INJECTION: ClassVar["VulnerabilityType"]
    RISKY_LICENSE: ClassVar["VulnerabilityType"]
    SESSION_REWRITING: ClassVar["VulnerabilityType"]
    SESSION_TIMEOUT: ClassVar["VulnerabilityType"]
    SQL_INJECTION: ClassVar["VulnerabilityType"]
    SSRF: ClassVar["VulnerabilityType"]
    STACK_TRACE_LEAK: ClassVar["VulnerabilityType"]
    TRUST_BOUNDARY_VIOLATION: ClassVar["VulnerabilityType"]
    UNMAINTAINED: ClassVar["VulnerabilityType"]
    UNTRUSTED_DESERIALIZATION: ClassVar["VulnerabilityType"]
    UNVALIDATED_REDIRECT: ClassVar["VulnerabilityType"]
    VERB_TAMPERING: ClassVar["VulnerabilityType"]
    WEAK_CIPHER: ClassVar["VulnerabilityType"]
    WEAK_HASH: ClassVar["VulnerabilityType"]
    WEAK_RANDOMNESS: ClassVar["VulnerabilityType"]
    X_CONTENT_TYPE_HEADER_MISSING: ClassVar["VulnerabilityType"]
    X_PATH_INJECTION: ClassVar["VulnerabilityType"]
    XSS: ClassVar["VulnerabilityType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


VulnerabilityType.ADMIN_CONSOLE_ACTIVE = VulnerabilityType("AdminConsoleActive")
VulnerabilityType.CODE_INJECTION = VulnerabilityType("CodeInjection")
VulnerabilityType.COMMAND_INJECTION = VulnerabilityType("CommandInjection")
VulnerabilityType.COMPONENT_WITH_KNOWN_VULNERABILITY = VulnerabilityType("ComponentWithKnownVulnerability")
VulnerabilityType.DANGEROUS_WORKFLOWS = VulnerabilityType("DangerousWorkflows")
VulnerabilityType.DEFAULT_APP_DEPLOYED = VulnerabilityType("DefaultAppDeployed")
VulnerabilityType.DEFAULT_HTML_ESCAPE_INVALID = VulnerabilityType("DefaultHtmlEscapeInvalid")
VulnerabilityType.DIRECTORY_LISTING_LEAK = VulnerabilityType("DirectoryListingLeak")
VulnerabilityType.EMAIL_HTML_INJECTION = VulnerabilityType("EmailHtmlInjection")
VulnerabilityType.END_OF_LIFE = VulnerabilityType("EndOfLife")
VulnerabilityType.HARDCODED_PASSWORD = VulnerabilityType("HardcodedPassword")
VulnerabilityType.HARDCODED_SECRET = VulnerabilityType("HardcodedSecret")
VulnerabilityType.HEADER_INJECTION = VulnerabilityType("HeaderInjection")
VulnerabilityType.HSTS_HEADER_MISSING = VulnerabilityType("HstsHeaderMissing")
VulnerabilityType.INSECURE_AUTH_PROTOCOL = VulnerabilityType("InsecureAuthProtocol")
VulnerabilityType.INSECURE_COOKIE = VulnerabilityType("InsecureCookie")
VulnerabilityType.INSECURE_JSP_LAYOUT = VulnerabilityType("InsecureJspLayout")
VulnerabilityType.LDAP_INJECTION = VulnerabilityType("LdapInjection")
VulnerabilityType.MALICIOUS_PACKAGE = VulnerabilityType("MaliciousPackage")
VulnerabilityType.MANDATORY_REMEDIATION = VulnerabilityType("MandatoryRemediation")
VulnerabilityType.NO_HTTP_ONLY_COOKIE = VulnerabilityType("NoHttpOnlyCookie")
VulnerabilityType.NO_SAME_SITE_COOKIE = VulnerabilityType("NoSameSiteCookie")
VulnerabilityType.NO_SQL_MONGO_DB_INJECTION = VulnerabilityType("NoSqlMongoDbInjection")
VulnerabilityType.PATH_TRAVERSAL = VulnerabilityType("PathTraversal")
VulnerabilityType.REFLECTION_INJECTION = VulnerabilityType("ReflectionInjection")
VulnerabilityType.RISKY_LICENSE = VulnerabilityType("RiskyLicense")
VulnerabilityType.SESSION_REWRITING = VulnerabilityType("SessionRewriting")
VulnerabilityType.SESSION_TIMEOUT = VulnerabilityType("SessionTimeout")
VulnerabilityType.SQL_INJECTION = VulnerabilityType("SqlInjection")
VulnerabilityType.SSRF = VulnerabilityType("Ssrf")
VulnerabilityType.STACK_TRACE_LEAK = VulnerabilityType("StackTraceLeak")
VulnerabilityType.TRUST_BOUNDARY_VIOLATION = VulnerabilityType("TrustBoundaryViolation")
VulnerabilityType.UNMAINTAINED = VulnerabilityType("Unmaintained")
VulnerabilityType.UNTRUSTED_DESERIALIZATION = VulnerabilityType("UntrustedDeserialization")
VulnerabilityType.UNVALIDATED_REDIRECT = VulnerabilityType("UnvalidatedRedirect")
VulnerabilityType.VERB_TAMPERING = VulnerabilityType("VerbTampering")
VulnerabilityType.WEAK_CIPHER = VulnerabilityType("WeakCipher")
VulnerabilityType.WEAK_HASH = VulnerabilityType("WeakHash")
VulnerabilityType.WEAK_RANDOMNESS = VulnerabilityType("WeakRandomness")
VulnerabilityType.X_CONTENT_TYPE_HEADER_MISSING = VulnerabilityType("XContentTypeHeaderMissing")
VulnerabilityType.X_PATH_INJECTION = VulnerabilityType("XPathInjection")
VulnerabilityType.XSS = VulnerabilityType("Xss")
